# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
#
# Copyright (C) 2022 University Münster.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for
# more details.

"""Version information for dnb_urn_service package.

This file is imported by ``dnb_urn_service.__init__``, and parsed by
``setup.py`` as well as ``docs/conf.py``.
"""

from __future__ import absolute_import, print_function

# Do not change the format of this next line. Doing so risks breaking
# setup.py and docs/conf.py

__version__ = "0.1.1"
